@@ -1,17 +1,3 @@
-/*
-  Racket
-  Copyright (c) 2004-2018 PLT Design Inc.
-  Copyright (c) 1995-2001 Matthew Flatt
-  All rights reserved.
-
-  Please see the full copyright in the documentation.
-
-  Originally based on:
-  libscheme
-  Copyright (c) 1994 Brent Benson
-  All rights reserved.
-*/
-
 /* SKIP */
 
 /* After modifying this file, `make exports' (you must have `racket'
@@ -386,17 +372,6 @@ MZ_EXTERN Scheme_Object *scheme_extract_one_cc_mark_to_tag(Scheme_Object *mark_s
 
 /* Internal */
 MZ_EXTERN Scheme_Object *scheme_do_eval(Scheme_Object *obj, int _num_rands, Scheme_Object **rands, int val);
-
-MZ_EXTERN Scheme_Object *scheme_eval_compiled_stx_string(Scheme_Object *expr, Scheme_Env *env,
-							 intptr_t shift, Scheme_Object *modidx);
-MZ_EXTERN Scheme_Object *scheme_load_compiled_stx_string(const char *str, intptr_t len);
-MZ_EXTERN Scheme_Object *scheme_compiled_stx_symbol(Scheme_Object *stx);
-
-MZ_EXTERN Scheme_Object *scheme_eval_compiled_sized_string(const char *str, int len, Scheme_Env *env);
-MZ_EXTERN Scheme_Object *scheme_eval_compiled_sized_string_with_magic(const char *str, int len, Scheme_Env *env, 
-								      Scheme_Object *magic_symbol, Scheme_Object *magic_val,
-								      int multi_ok);
-
 MZ_EXTERN void scheme_detach_multple_array(Scheme_Object **a);
 
 /*========================================================================*/
@@ -1023,39 +998,36 @@ MZ_EXTERN Scheme_Object *scheme_make_namespace(int argc, Scheme_Object *argv[]);
 
 MZ_EXTERN void scheme_add_global(const char *name, Scheme_Object *val, Scheme_Env *env);
 MZ_EXTERN void scheme_add_global_symbol(Scheme_Object *name, Scheme_Object *val,
-			      Scheme_Env *env);
+                                        Scheme_Env *env);
 
 MZ_EXTERN Scheme_Object *scheme_make_envunbox(Scheme_Object *value);
 
 MZ_EXTERN Scheme_Object *scheme_lookup_global(Scheme_Object *symbol, Scheme_Env *env);
 
 MZ_EXTERN Scheme_Bucket *scheme_global_bucket(Scheme_Object *symbol, Scheme_Env *env);
-MZ_EXTERN Scheme_Bucket *scheme_global_keyword_bucket(Scheme_Object *symbol, Scheme_Env *env);
 MZ_EXTERN Scheme_Bucket *scheme_module_bucket(Scheme_Object *mod, Scheme_Object *var, int pos, Scheme_Env *env);
 
 MZ_EXTERN Scheme_Object *scheme_builtin_value(const char *name); /* convenience */
 
 MZ_EXTERN void scheme_set_global_bucket(char *proc, Scheme_Bucket *var, Scheme_Object *val,
                                         int set_undef);
-MZ_EXTERN void scheme_install_macro(Scheme_Bucket *b, Scheme_Object *v);
 
-
-MZ_EXTERN void scheme_save_initial_module_set(Scheme_Env *env);
 MZ_EXTERN Scheme_Env *scheme_primitive_module(Scheme_Object *name, Scheme_Env *for_env);
 MZ_EXTERN void scheme_finish_primitive_module(Scheme_Env *env);
 MZ_EXTERN void scheme_set_primitive_module_phaseless(Scheme_Env *env, int phaseless);
 MZ_EXTERN void scheme_protect_primitive_provide(Scheme_Env *env, Scheme_Object *name);
 
 MZ_EXTERN Scheme_Object *scheme_make_modidx(Scheme_Object *path,
-				  Scheme_Object *base,
-				  Scheme_Object *resolved);
-
-MZ_EXTERN Scheme_Object *scheme_apply_for_syntax_in_env(Scheme_Object *proc, Scheme_Env *env);
+                                            Scheme_Object *base,
+                                            Scheme_Object *resolved);
 
 MZ_EXTERN Scheme_Object *scheme_dynamic_require(int argc, Scheme_Object *argv[]);
+MZ_EXTERN Scheme_Object *scheme_dynamic_require_reader(int argc, Scheme_Object *argv[]);
 MZ_EXTERN Scheme_Object *scheme_namespace_require(Scheme_Object *);
 
 MZ_EXTERN int scheme_is_module_path(Scheme_Object *);
+MZ_EXTERN int scheme_is_module_path_index(Scheme_Object *);
+MZ_EXTERN int scheme_is_resolved_module_path(Scheme_Object *);
 
 MZ_EXTERN Scheme_Object *scheme_datum_to_kernel_stx(Scheme_Object *e);
 
